import React, { forwardRef, useImperativeHandle } from 'react';
import Animated, { useSharedValue, withDelay, withTiming } from 'react-native-reanimated';
import { StyleSheet, Text, View } from 'react-native';
import useTimer from './useTimer';
const DEFAULT_ANIMATION_DELAY = 0;
const DEFAULT_ANIMATION_DISTANCE = 80;
const DEFAULT_ANIMATION_DURATION = 200;
function Stopwatch(_ref, ref) {
  let {
    animationDelay = DEFAULT_ANIMATION_DELAY,
    animationDistance = DEFAULT_ANIMATION_DISTANCE,
    animationDuration = DEFAULT_ANIMATION_DURATION,
    containerStyle,
    enterAnimationType = 'slide-in-up',
    digitStyle,
    initialTimeInMs,
    leadingZeros = 1,
    onFinish,
    separatorStyle,
    textCharStyle,
    trailingZeros = 1
  } = _ref;
  const {
    tensOfMs,
    lastDigit,
    tens,
    minutes,
    play,
    reset,
    pause,
    getSnapshot
  } = useTimer(initialTimeInMs, onFinish);
  useImperativeHandle(ref, () => ({
    play,
    pause,
    reset,
    getSnapshot
  }));
  const isSecondsDigitMounted = useSharedValue(false);
  const isTensOfSecondsDigitMounted = useSharedValue(false);
  const isMinutesDigitMounted = useSharedValue(false);
  const createEntering = isFirstRender => values => {
    'worklet';

    if (!isFirstRender.value) {
      // Skip entering animation on first render
      isFirstRender.value = true;
      return {
        initialValues: {},
        animations: {}
      };
    }
    const animations = {
      originY: withDelay(animationDelay, withTiming(values.targetOriginY, {
        duration: animationDuration
      }))
    };
    const enterDirection = enterAnimationType === 'slide-in-up' ? -1 : 1;
    const initialValues = {
      originY: values.targetOriginY + animationDistance * enterDirection
    };
    return {
      initialValues,
      animations
    };
  };
  const exiting = values => {
    'worklet';

    const exitDirection = enterAnimationType === 'slide-in-up' ? 1 : -1;
    const animations = {
      originY: withDelay(animationDelay, withTiming(values.currentOriginY + animationDistance * exitDirection, {
        duration: animationDuration
      }))
    };
    const initialValues = {
      originY: values.currentOriginY
    };
    return {
      initialValues,
      animations
    };
  };

  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  const {
    width,
    ...textCharStyleWithoutWidth
  } = StyleSheet.flatten(textCharStyle || {});
  return /*#__PURE__*/React.createElement(View, {
    style: [styles.container, containerStyle]
  }, leadingZeros === 2 && /*#__PURE__*/React.createElement(Text, {
    style: [styles.defaultCharStyle, textCharStyleWithoutWidth, digitStyle]
  }, "0"), /*#__PURE__*/React.createElement(Animated.Text, {
    key: `${minutes}-minutes`,
    style: [styles.defaultCharStyle, textCharStyleWithoutWidth, digitStyle],
    entering: createEntering(isMinutesDigitMounted),
    exiting: exiting
  }, minutes), /*#__PURE__*/React.createElement(Text, {
    style: [styles.defaultCharStyle, textCharStyleWithoutWidth, separatorStyle]
  }, ":"), /*#__PURE__*/React.createElement(Animated.Text, {
    key: `${tens}-tens`,
    style: [styles.defaultCharStyle, textCharStyleWithoutWidth, digitStyle],
    entering: createEntering(isTensOfSecondsDigitMounted),
    exiting: exiting
  }, tens), /*#__PURE__*/React.createElement(Animated.Text, {
    key: `${lastDigit}-count`,
    style: [styles.defaultCharStyle, textCharStyleWithoutWidth, digitStyle],
    entering: createEntering(isSecondsDigitMounted),
    exiting: exiting
  }, lastDigit), trailingZeros > 0 && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Text, {
    style: [styles.defaultCharStyle, textCharStyleWithoutWidth, separatorStyle]
  }, ","), /*#__PURE__*/React.createElement(Text, {
    style: [styles.defaultCharStyle, textCharStyleWithoutWidth, digitStyle]
  }, tensOfMs >= 10 ? String(tensOfMs).charAt(0) : 0), trailingZeros === 2 && /*#__PURE__*/React.createElement(Text, {
    style: [styles.defaultCharStyle, textCharStyleWithoutWidth, digitStyle]
  }, tensOfMs >= 10 ? String(tensOfMs).charAt(1) : String(tensOfMs).charAt(0))));
}
const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    alignItems: 'center',
    overflow: 'hidden'
  },
  defaultCharStyle: {
    textAlign: 'center'
  }
});
const StopwatchTimer = /*#__PURE__*/forwardRef(Stopwatch);
export default StopwatchTimer;
//# sourceMappingURL=StopwatchTimer.js.map